extensions library

Classes

DerivedValueListenable<T>
A read-only ValueListenable derived from one or more source listenables.
StreamValueNotifier<T>
A ValueNotifier kept in sync with a Stream.

Extensions

FHUBoolNotifierEx on bool
Extension on bool to provide easy access to creating a ValueNotifier for boolean values.
FHUBrightnessNotifierEx on Brightness
Extension on Brightness to provide easy access to creating a ValueNotifier for Brightness.
FHUColorNotifierEx on Color
Extension on Color to provide easy access to creating a ValueNotifier for Color objects.
FHUDateTimeNotifierEx on DateTime
Extension on DateTime to provide easy access to creating a ValueNotifier for DateTime objects.
FHUDoubleNotifierEx on double
Extension on double to provide easy access to creating a ValueNotifier for double values.
FHUDurationNotifierEx on Duration
Extension on Duration to provide easy access to creating a ValueNotifier for duration values.
FHUIntNotifierEx on int
Extension on int to provide easy access to creating a ValueNotifier for integer values.
FHUIterableNotifierEx on Iterable<E>
Extension on Iterable<E> to provide easy access to collection ValueNotifier instances.
FHUListenableExtension on Listenable
Extension on Listenable to integrate with ListenableBuilder.
FHUListenablesExtension on List<Listenable?>
Extension on a list of Listenable objects to integrate with ListenablesBuilder.
FHUListNotifierEx on List<E>
Extension on List<E> to provide easy access to creating a ValueNotifier for lists.
FHUMapNotifierEx on Map<K, V>
Extension on Map<K, V> to provide easy access to creating a ValueNotifier for maps.
FHUNumNotifierEx on num
Extension on num to provide easy access to creating a ValueNotifier for numeric types.
FHUSetNotifierEx on Set<E>
Extension on Set<E> to provide easy access to creating a ValueNotifier for sets.
FHUStreamToValueNotifier on Stream<T>
Extension on Stream<T> to convert any stream into a ValueNotifier<T>.
FHUStringNotifierEx on String
Extension on String to provide easy access to creating a ValueNotifier for String values.
FHUThemeModeNotifierEx on ThemeMode
Extension on ThemeMode to provide easy access to creating a ValueNotifier for ThemeMode.
FHUUriNotifierEx on Uri
Extension on Uri to provide easy access to creating a ValueNotifier for Uri objects.
FHUValueListenableExtension on ValueListenable<T>
Extension on ValueListenable to seamlessly create a ValueListenableBuilder widget.
FHUValueListenableExtensions on ValueListenable<T>
Reactive helpers for listening to any ValueListenable.
FHUValueNotifierExtension on T
Extension on any non-nullable Object.
FHUValueNotifierExtensions on ValueNotifier<T>
Shorthand accessors for reading and writing ValueNotifier.value.

Typedefs

ValueEquality<T> = bool Function(T previous, T next)
Equality function used by DerivedValueListenable to suppress unchanged derived values.