notifier_classes library

Classes

BoolNotifier
allows to quickly create a ValueNotifier of type bool.
BrightnessNotifier
Stores the current Brightness in a listenable object.
ColorNotifier
allows to quickly create a ValueNotifier of type Color.
DateTimeNotifier
create a ValueNotifier of type DateTime, which reacts just like normal DateTime, but with notifier capabilities.
DoubleNotifier
allows to quickly create a ValueNotifier of type double.
DurationNotifier
create a ValueNotifier of type Duration, which reacts just like normal Duration, but with notifier capabilities.
IntNotifier
allows to quickly create a ValueNotifier of type int.
ListNotifier<E>
create a ValueNotifier of type List, which reacts just like normal List, but with notifier capabilities.
MapNotifier<K, V>
create a ValueNotifier of type Map, which reacts just like normal Map, but with notifier capabilities.
NumNotifier
allows to quickly create a ValueNotifier of type num. allows to quickly create a ValueNotifier of type num.
SetNotifier<E>
A ValueNotifier wrapper around a mutable Set.
StringNotifier
allows to quickly create a ValueNotifier of type String.
ThemeModeNotifier
Stores the app's current ThemeMode in a listenable object.
UriNotifier
create a ValueNotifier of type Uri, which reacts just like normal Uri, but with notifier capabilities.

Extensions

BrightnessNotifierEx on ValueNotifier<Brightness>
Convenience getters and setters for a ValueNotifier of Brightness.
FHUBoolValueNotifierExtension on ValueNotifier<bool>
BoolValueNotifierExtension
FHUColorValueNotifierExtension on ValueListenable<Color>
Extension: ColorValueNotifierExtension
FHUDoubleValueNotifierExtension on ValueListenable<double>
DoubleValueNotifierExtension
FHUIntValueNotifierExtension on ValueListenable<int>
IntValueNotifierExtension
FHUNumericValueNotifierExtension on ValueNotifier<num>
NumericValueNotifierExtension
ThemeModeNotifierEx on ValueNotifier<ThemeMode>
Convenience getters and setters for a ValueNotifier of ThemeMode.