DurationNotifier class
create a ValueNotifier of type Duration, which reacts just like normal Duration, but with notifier capabilities.
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
Duration> - DurationNotifier
- Implemented types
- Available extensions
Constructors
- DurationNotifier(Duration initial)
- Creates a notifier backed by an initial Duration value.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- inDays → int
-
documentation available in the original overridden method.
no setteroverride
- inHours → int
-
documentation available in the original overridden method.
no setteroverride
- inMicroseconds → int
-
documentation available in the original overridden method.
no setteroverride
- inMilliseconds → int
-
documentation available in the original overridden method.
no setteroverride
- inMinutes → int
-
documentation available in the original overridden method.
no setteroverride
- inSeconds → int
-
documentation available in the original overridden method.
no setteroverride
- isNegative → bool
-
documentation available in the original overridden method.
no setteroverride
- notifier → DurationNotifier
-
Available on Duration, provided by the FHUDurationNotifierEx extension
Creates a DurationNotifier instance from the current Duration value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ Duration
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
abs(
) → Duration -
documentation available in the original overridden method.
override
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
builder(
Widget builder(BuildContext context)) → Widget -
Available on Listenable, provided by the FHUListenableExtension extension
Creates a ListenableBuilder widget that listens to this Listenable. -
compareTo(
Duration other) → int -
documentation available in the original overridden method.
override
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
override
-
refresh(
) → void - Re-emits the current duration without changing it.
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
Duration newValue) → void - similar to value setter but this one force trigger the notifyListeners() event if newValue == value.
Operators
-
operator *(
num factor) → Duration -
documentation available in the original overridden method.
override
-
operator +(
Duration other) → Duration -
documentation available in the original overridden method.
override
-
operator -(
Duration other) → Duration -
documentation available in the original overridden method.
override
-
operator <(
Duration other) → bool -
documentation available in the original overridden method.
override
-
operator <=(
Duration other) → bool -
documentation available in the original overridden method.
override
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator >(
Duration other) → bool -
documentation available in the original overridden method.
override
-
operator >=(
Duration other) → bool -
documentation available in the original overridden method.
override
-
operator unary-(
) → Duration -
documentation available in the original overridden method.
override
-
operator ~/(
int quotient) → Duration -
documentation available in the original overridden method.
override